@@ -1,7 +1,7 @@
 
 package Mail::Box::Search;
 use vars '$VERSION';
-$VERSION = '2.041';
+$VERSION = '2.042';
 use base 'Mail::Reporter';
 
 use strict;
@@ -118,7 +118,7 @@ sub searchPart($)
 
    # Handle multipart parts.
 
-   if($body->isMultipart || $body->isNested)
+   if($body->isMultipart)
    {   return $matched unless $self->{MBS_multiparts};
        my $no_delayed = not $self->{MBS_delayed};
        @bodies = ($body->preamble, $body->epilogue);
@@ -131,6 +131,10 @@ sub searchPart($)
            return $matched if $matched && !$self->{MBS_deliver};
        }
    }
+   elsif($body->isNested)
+   {   return $matched unless $self->{MBS_multiparts};
+       $matched += $self->searchPart($body->nested);
+   }
    else
    {   @bodies = ($body);
    }
