@@ -3,8 +3,9 @@ use warnings;
 
 package Mail::Message::Part;
 use vars '$VERSION';
-$VERSION = '2.041';
+$VERSION = '2.042';
 use base 'Mail::Message';
+use Scalar::Util 'weaken';
 
 use Carp;
 
@@ -18,7 +19,9 @@ sub init($)
     confess "No container specified for part.\n"
         unless exists $args->{container};
 
-    $self->{MMP_container} = $args->{container};
+    weaken($self->{MMP_container})
+       if $self->{MMP_container} = $args->{container};
+
     $self;
 }
 
@@ -36,7 +39,7 @@ sub coerce($@)
     my $message = $thing->isa('Mail::Box::Message') ? $thing->clone : $thing;
 
     my $part    = $class->SUPER::coerce($message);
-    $part->{MMP_container} = $container;
+    $part->container($container);
     $part;
 }
 
@@ -67,7 +70,10 @@ sub buildFromBody($$;@)
 
 sub container(;$)
 {   my $self = shift;
-    @_ ? $self->{MMP_container} = shift : $self->{MMP_container};
+    return $self->{MMP_container} unless @_;
+
+    $self->{MMP_container} = shift;
+    weaken($self->{MMP_container});
 }
 
 #------------------------------------------
